@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
-from cms.admin.placeholderadmin import FrontendEditableAdminMixin
-from django.contrib import admin
+from __future__ import absolute_import, print_function, unicode_literals
 
 from aldryn_apphooks_config.admin import BaseAppHookConfig, ModelAppHookConfig
+from cms.admin.placeholderadmin import FrontendEditableAdminMixin
+from django.contrib import admin
 
 from .models import Article, ExampleConfig
 
@@ -12,8 +13,8 @@ class ArticleAdmin(FrontendEditableAdminMixin,
                    admin.ModelAdmin):
     list_display = ('title', 'section', 'slug')
     app_config_attribute = 'section'
-    app_config_selection_title = u'Select app config'
-    app_config_selection_desc = u'Select the app config for the new object'
+    app_config_selection_title = 'Select app config'
+    app_config_selection_desc = 'Select the app config for the new object'
     app_config_values = {
         'published_default': 'published'
     }
@@ -22,6 +23,13 @@ admin.site.register(Article, ArticleAdmin)
 
 
 class ExampleConfigAdmin(BaseAppHookConfig):
+
+    def get_fieldsets(self, request, obj):
+        return [
+            (None, {'fields': ('type', 'namespace', 'app_title')}),
+            ('Config', {'fields': self.get_config_fields()})
+        ]
+
     def get_config_fields(self):
         return ['config.property', 'config.published_default']
 
