@@ -1,28 +1,26 @@
 # -*- coding: utf-8 -*-
-from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from __future__ import absolute_import, print_function, unicode_literals
 
 from aldryn_apphooks_config.fields import AppHookConfigField
 from aldryn_apphooks_config.managers import AppHookConfigManager
-from aldryn_apphooks_config.managers.parler import (
-    AppHookConfigTranslatableManager
-)
+from aldryn_apphooks_config.managers.parler import AppHookConfigTranslatableManager
+from django.db import models
 from parler.models import TranslatableModel, TranslatedFields
 
-from .cms_appconfig import ExampleConfig, AnotherExampleConfig
+from .cms_appconfig import AnotherExampleConfig, ExampleConfig
 
 
 class Article(models.Model):
-    title = models.CharField(_('title'), max_length=234)
+    title = models.CharField('title', max_length=234)
     slug = models.SlugField()
-    section = AppHookConfigField(ExampleConfig, verbose_name=_('section'))
+    section = AppHookConfigField(ExampleConfig, verbose_name='section')
     published = models.BooleanField(default=True, blank=True)
 
     objects = AppHookConfigManager()
 
 
 class News(Article):
-    config = AppHookConfigField(AnotherExampleConfig, verbose_name=_('config'))
+    config = AppHookConfigField(AnotherExampleConfig, verbose_name='config')
 
     objects = AppHookConfigManager()
 
@@ -32,6 +30,10 @@ class TranslatableArticle(TranslatableModel):
         title=models.CharField('title', max_length=234),
         slug=models.SlugField()
     )
-    section = AppHookConfigField(ExampleConfig, verbose_name=_('section'))
+    section = AppHookConfigField(ExampleConfig, verbose_name='section')
 
     objects = AppHookConfigTranslatableManager()
+
+
+class NotApphookedModel(models.Model):
+    title = models.CharField('title', max_length=234)
